pub struct SourceOptions {
pub upstream: Option<String>,
pub model: Option<String>,
pub llm_port: u16,
}Fields
upstream: Option<String>Connect to an already-running OpenAI-compatible upstream (http:// or https:// base URL)
model: Option<String>Model to start with vLLM, or the model name to use with --upstream.
When omitted alongside --upstream, the first model served by the upstream is used.
llm_port: u16vLLM port when starting a model