validate_claude_model

Function validate_claude_model 

pub fn validate_claude_model(model: &str) -> Result<(), String>
Validates that a Claude Code model name is a slash-free served alias.

Errors

Returns an error when the model name contains /, which Claude Code does not accept for custom model names.