pub struct OidcAuthenticator { /* private fields */ }Implementations
Sourceimpl OidcAuthenticator
impl OidcAuthenticator
Sourcepub async fn discover(config: OidcConfig) -> Result<Self, OidcAuthError>
pub async fn discover(config: OidcConfig) -> Result<Self, OidcAuthError>
Discover an OIDC provider and cache its initial verification keys.
Errors
Returns an error when provider discovery or the JSON Web Key Set (JWKS) request fails, or when the discovered metadata is inconsistent.