pub fn convert_response(resp: ProxyResponse) -> ResponseExpand description
Panics
Panics if the response builder produces an invalid response (unreachable in practice).
pub fn convert_response(resp: ProxyResponse) -> ResponsePanics if the response builder produces an invalid response (unreachable in practice).