pub fn executor_error_response(err: ExecutorError) -> ResponseExpand description
Panics
Panics if the response builder produces an invalid response (unreachable in practice).
pub fn executor_error_response(err: ExecutorError) -> ResponsePanics if the response builder produces an invalid response (unreachable in practice).